@@ -47,15 +47,16 @@ import click
 from consolekit.terminal_colours import resolve_color_default
 from consolekit.utils import abort
 from domdf_python_tools.paths import PathPlus
+from domdf_python_tools.stringlist import StringList
 from domdf_python_tools.terminal_colours import Fore
 from domdf_python_tools.typing import PathLike
 from packaging.specifiers import Specifier
 from packaging.version import Version
+from shippinglabel.requirements import ComparableRequirement, combine_requirements, read_requirements
 
 # this package
 from repo_helper import __version__
 from repo_helper.configuration import parse_yaml
-from repo_helper.requirements_tools import ComparableRequirement, combine_requirements, read_requirements
 from repo_helper.utils import traverse_to_file
 
 __all__ = ["Builder", "build_wheel", "build_sdist"]
@@ -141,11 +142,9 @@ class Builder:
 		"""
 
 		if self.config["stubs_package"]:
-			return posixpath.join(
-					self.config["source_dir"], f"{self.config['import_name'].replace('.', '/')}-stubs"
-					)
+			return posixpath.join(self.config["source_dir"], f"{self.config['import_name'].split('.')[0]}-stubs")
 		else:
-			return posixpath.join(self.config["source_dir"], self.config["import_name"].replace(".", "/"))
+			return posixpath.join(self.config["source_dir"], self.config["import_name"].split(".")[0])
 
 	def iter_source_files(self) -> Iterator[PathPlus]:
 		pkgdir = self.repo_dir / self.pkg_dir
@@ -288,7 +287,18 @@ class Builder:
 		"""  # noqa: D400
 
 		cfg_parser = configparser.ConfigParser()
-		cfg_parser.read_string("[console_scripts]\n" + "\n".join(self.config["console_scripts"]))
+
+		buf = StringList()
+		if self.config["console_scripts"]:
+			buf.append("[console_scripts]")
+			buf.extend(self.config["console_scripts"])
+
+		for group, entry_points in self.config["entry_points"].items():
+
+			buf.append(f"[{group}]")
+			buf.extend(entry_points)
+
+		cfg_parser.read_string(str(buf))
 		cfg_io = StringIO()
 		cfg_parser.write(cfg_io)
 
