@@ -86,6 +86,7 @@ from repo_helper.configuration.packaging import (
 		additional_requirements_files,
 		additional_setup_args,
 		console_scripts,
+		entry_points,
 		extras_require,
 		manifest_additional,
 		parse_additional_setup_args,
@@ -300,6 +301,7 @@ all_values: List[ConfigVarMeta] = [
 		mypy_version,
 		use_experimental_backend,
 		pre_commit_exclude,
+		entry_points,
 		]
 
 
@@ -362,6 +364,9 @@ class RepoHelperParser(Parser):
 		if (repo_path / parsed_config_vars["import_name"].replace(".", "/") / "py.typed").is_file():
 			add_classifier("Typing :: Typed")
 
+		if parsed_config_vars["use_experimental_backend"]:
+			parsed_config_vars["tox_build_requirements"].append("repo_helper")
+
 		return parsed_config_vars
 
 
