@@ -35,12 +35,13 @@ import jinja2
 from domdf_python_tools.paths import PathPlus
 from domdf_python_tools.typing import PathLike
 from packaging.requirements import Requirement
+from shippinglabel import normalize
+from shippinglabel.requirements import RequirementsManager, read_requirements
 
 # this package
 from repo_helper.configupdater2 import ConfigUpdater
 from repo_helper.files import management
 from repo_helper.files.linting import code_only_warning, lint_fix_list, lint_warn_list
-from repo_helper.requirements_tools import RequirementsManager, normalize, read_requirements
 from repo_helper.utils import IniConfigurator, indent_join
 
 __all__ = [
@@ -109,11 +110,17 @@ class ToxConfig(IniConfigurator):
 				source_files.append(posixpath.join(self._globals["source_dir"], f"{file}.py"))
 
 		elif self._globals["stubs_package"]:
-			directory = posixpath.join(self._globals["source_dir"], f"{self._globals['import_name'].replace('.', '/')}-stubs")
+			directory = posixpath.join(
+					self._globals["source_dir"],
+					f"{self._globals['import_name'].replace('.', '/')}-stubs",
+					)
 			source_files.append(directory)
 
 		else:
-			directory = posixpath.join(self._globals["source_dir"], self._globals["import_name"].replace(".", "/"))
+			directory = posixpath.join(
+					self._globals["source_dir"],
+					self._globals["import_name"].replace(".", "/"),
+					)
 			source_files.append(directory)
 
 		if self._globals["enable_tests"]:
@@ -258,9 +265,9 @@ class ToxConfig(IniConfigurator):
 		self._ini["testenv:build"]["skip_install"] = True
 		self._ini["testenv:build"]["changedir"] = "{toxinidir}"
 		self._ini["testenv:build"]["deps"] = indent_join([
-				"twine",
-				"pep517",
-				"check-wheel-contents",
+				"twine>=3.2.0",
+				"pep517>=0.9.1",
+				"check-wheel-contents>=0.1.0",
 				*self["tox_build_requirements"],
 				])
 		self._ini["testenv:build"]["commands"] = indent_join([
@@ -373,9 +380,9 @@ class ToxConfig(IniConfigurator):
 			self._ini["testenv:coverage"]["whitelist_externals"] = "/bin/bash"
 			self._ini["testenv:coverage"]["changedir"] = "{toxinidir}"
 
-			coverage_deps = ["coverage"]
+			coverage_deps = ["coverage>=5"]
 			if self["pypi_name"] != "coverage_pyver_pragma":
-				coverage_deps.append("coverage_pyver_pragma")
+				coverage_deps.append("coverage_pyver_pragma>=0.0.6")
 
 			self._ini["testenv:coverage"]["deps"] = indent_join(coverage_deps)
 
